@@ -8,11 +8,11 @@ class Agent(object):
     def __init__(self, app_name: str, key_pair: key_pair_format, aes_key: bytes, hmac_key: bytes) -> None:
         self.__hmac = lambda _: mac(_, hmac_key)
         self.__skey = lambda: bytes(randb(len(aes_key))[i] ^ aes_key[i] for i in range(len(aes_key)))
-        self.__aese = lambda _, __: AESCipher(_).encrypt(__)
-        self.__aesd = lambda _, __: AESCipher(
-            EasyRSA(private_key=key_pair["private_key"]).decrypt(_)
-        ).decrypt(__)
-        self.__rsae = lambda _: EasyRSA(public_key=key_pair["public_key"]).encrypt(_)
+        self.__aese = lambda k, v: AESCipher(k).encrypt(v)
+        self.__aesd = lambda k, v: AESCipher(
+            EasyRSA(private_key=key_pair["private_key"]).decrypt(k)
+        ).decrypt(v)
+        self.__rsae = lambda k: EasyRSA(public_key=key_pair["public_key"]).encrypt(k)
         self.__app_name = self.__hmac(app_name)
 
     @staticmethod
